=======
Credits
=======

When you contribute to icalendar, please add your name to this list of contributors.
Please use the format of your public identity as either your name or GitHub username, followed by the URL to your GitHub profile.
Do not use an email address, as those may get harvested or become invalid in the future.

.. code-block:: rst

    - GivenName Surname <https://github.com/github_username>_
    - github_username <https://github.com/github_username>_

The following people have made contributions to icalendar.
The maintainers of icalendar are grateful for their support.

Maintainers
-----------

- `@geier <https://github.com/geier>`_
- `@jacadzaca <https://github.com/jacadzaca>`_
- `Nicco Kunzmann <https://github.com/niccokunzmann>`_


Original author
---------------

- Max M <maxm@mxm.dk>


Contributors
------------

- Abe Hanoka <abe@habet.dev>
- Alexander Pitkin <peleccom@gmail.com>
- Andreas Zeidler <az@zitc.de>
- Andreas Ruppen <andreas.ruppen@gmail.com>
- Andrey Nikolaev <nikolaeff@gmail.com>
- Barak Michener <me@barakmich.com>
- Bastian Wegge <wegge@crossbow.de>
- `Chase Naples <https://github.com/cnaples79>`_
- Christian Geier <contact@lostpackets.de>
- Christophe de Vienne <cdevienne@gmail.com>
- cillianderoiste <cillian.deroiste@gmail.com>
- Clive Stevens <clivest2@gmail.com>
- Dai MIKURUBE <dmikurube@acm.org>
- Dalton Durst <github@daltondur.st>
- Dan Stovall <dbstovall@gmail.com>
- `David Venhoff <https://github.com/david-venhoff>`_
- Eric Hanchrow <erich@cozi.com>
- Eric Wieser <wieser.eric@gmail.com>
- Erik Simmler <tgecho@gmail.com>
- Felix Stupp <felix.stupp@banananet.work>
- `fitnr <https://github.com/fitnr>`_
- George V. Reilly <george@reilly.org>
- hajdbo <boris@hajduk.org>
- ilya
- Jannis Leidel <jannis@leidel.info>
- Jeffrey Whewhetu <jeffwhewhetu@gmail.com>
- Jeroen F.J. Laros <jlaros@fixedpoint.nl>
- Jeroen van Meeuwen (Kolab Systems) <vanmeeuwen@kolabsys.com>
- Jochen Sprickerhof <icalendar@jochen.sprickerhof.de>
- Johannes Raggam <johannes@raggam.co.at>
- Jordan Kiang <jordan@cozi.com>
- `Jouni K. Seppänen <https://github.com/jkseppan>`_
- Kamil Mańkowski <kam193@wp.pl>
- Klaus Klein <kleink+github@kleink.org>
- Laurent Lasudry <lasudry@gmail.com>
- Lennart Regebro <lregebro@nuxeo.com>
- Léo S <leo@naeka.fr>
- Marc Egli <frog32@me.com>
- Markus Unterwaditzer <markus@unterwaditzer.net>
- Martijn Faassen <faassen@infrae.com>
- Martin Melin <git@martinmelin.com>
- Matt Lewis <git@semiprime.com>
- Maurits van Rees <maurits@vanrees.org>
- Mauro Amico <mauro.amico@gmail.com>
- Michael Smith <msmith@fluendo.com>
- Michał Górny <mgorny@gentoo.org>
- Mikael Frykholm <mikael@frykholm.com>
- `Natasha Mattson <https://github.com/natashamm>`_
- `NikEasY <https://github.com/NikEasY>`_
- Olivier Grisel <ogrisel@nuxeo.com>
- Pavel Repin <prepin@gmail.com>
- Pedro Ferreira <jose.pedro.ferreira@cern.ch>
- Pronoy <lukex9442@gmail.com>
- Rembane <andeke@gmail.com>
- Robert Niederreiter <rnix@squarewave.at>
- Robert Spralja <robert.spralja@gmail.com>
- Rok Garbas <rok@garbas.si>
- Ronan Dunklau <ronan@dunklau.fr>
- Russ <russ@rw.id.au>
- `SanthoshMani1 <https://github.com/SanthoshMani1>`_
- `Sashank Bhamidi <https://github.com/SashankBhamidi>`_
- `Serif OZ <https://github.com/SerifOZ>`_
- Sidnei da Silva <sidnei@enfoldsystems.com>
- Simon Ruderich <simon@ruderich.org>
- `Soham Dutta <https://github.com/NP-compete>`_
- spanktar <spanky@kapanka.com>
- Stanislav Láznička <slaznick@redhat.com>
- Stanislav Ochotnicky <sochotnicky@redhat.com>
- Stefan Schwarzer <sschwarzer@sschwarzer.net>
- `Steve Piercy <https://github.com/stevepiercy>`_
- `Tanmay Maheshwari <https://github.com/LilSuperUser>`_
- `Tariq <https://github.com/Horisyre>`_
- tgecho <tgecho@gmail.com>
- Thomas Bruederli <thomas@roundcube.net>
- Thomas Weißschuh <thomas@t-8ch.de>
- tisto <tisto@plone.org>
- Tobias Brox <tobias@redpill-linpro.com>
- TomTry <tom.try@gmail.com>
- Victor Varvaryuk <victor.varvariuc@gmail.com>
- Ville Skyttä <ville.skytta@iki.fi>
- Wichert Akkerman <wichert@wiggy.net>
- Howard Liao <howard940114@gmail.com>
- Zepyoor Khechadoorian <zepyoorkhechadoorian@gmail.com>

Complete list
-------------

Although this list might not be complete, as some contributors either didn't know that they could add their name to this file or didn't want to be added, you can find out who contributed to icalendar.

On GitHub, from the icalendar home page, click the link `Contributors <https://github.com/collective/icalendar/graphs/contributors>`_.

Alternatively from your local git checkout, issue the following command, which prints a list of all contributors sorted by their name and commit email address, and the count of commits for each one.

.. code-block:: shell

    git shortlog -s -e


History
-------
`Max M <http://www.mxm.dk>`_ had often needed to parse and generate iCalendar files.
Finally, he got tired of writing ad-hoc tools.
This package is his attempt at making an iCalendar package for Python.
The inspiration has come from the email package in the standard library, which he thinks is pretty simple, yet efficient and powerful.
